@@ -4,11 +4,22 @@ from collections.abc import Mapping
 from typing import TYPE_CHECKING, Any, Literal, Protocol, TypeVar, Union
 
 from narwhals._compliant import CompliantDataFrame, CompliantLazyFrame, CompliantSeries
+from narwhals._native import (
+    IntoDataFrame,
+    IntoDataFrameT,
+    IntoFrame,
+    IntoFrameT,
+    IntoLazyFrame,
+    IntoLazyFrameT,
+    IntoSeries,
+    IntoSeriesT,
+)
 from narwhals._typing import Backend, EagerAllowed, IntoBackend, LazyAllowed
 
 if TYPE_CHECKING:
     import datetime as dt
-    from collections.abc import Iterable, Sequence, Sized
+    import os
+    from collections.abc import Sequence
     from decimal import Decimal
     from types import ModuleType
 
@@ -19,29 +30,11 @@ if TYPE_CHECKING:
     from typing_extensions import TypeAlias
 
     from narwhals import dtypes
-    from narwhals._namespace import _NativeIbis
     from narwhals.dataframe import DataFrame, LazyFrame
     from narwhals.expr import Expr
     from narwhals.schema import Schema
     from narwhals.series import Series
 
-    # All dataframes supported by Narwhals have a
-    # `columns` property. Their similarities don't extend
-    # _that_ much further unfortunately...
-    class NativeFrame(Protocol):
-        @property
-        def columns(self) -> Any: ...
-
-        def join(self, *args: Any, **kwargs: Any) -> Any: ...
-
-    class NativeDataFrame(Sized, NativeFrame, Protocol): ...
-
-    class NativeLazyFrame(NativeFrame, Protocol):
-        def explain(self, *args: Any, **kwargs: Any) -> Any: ...
-
-    class NativeSeries(Sized, Iterable[Any], Protocol):
-        def filter(self, *args: Any, **kwargs: Any) -> Any: ...
-
     class SupportsNativeNamespace(Protocol):
         def __native_namespace__(self) -> ModuleType: ...
 
@@ -114,35 +107,6 @@ as it can either accept a `nw.Expr` (e.g. `df.select(nw.col('a'))`) or a string
 which will be interpreted as a `nw.Expr`, e.g. `df.select('a')`.
 """
 
-IntoDataFrame: TypeAlias = "NativeDataFrame"
-"""Anything which can be converted to a Narwhals DataFrame.
-
-Use this if your function accepts a narwhalifiable object but doesn't care about its backend.
-
-Examples:
-    >>> import narwhals as nw
-    >>> from narwhals.typing import IntoDataFrame
-    >>> def agnostic_shape(df_native: IntoDataFrame) -> tuple[int, int]:
-    ...     df = nw.from_native(df_native, eager_only=True)
-    ...     return df.shape
-"""
-
-IntoLazyFrame: TypeAlias = Union["NativeLazyFrame", "_NativeIbis"]
-
-IntoFrame: TypeAlias = Union["IntoDataFrame", "IntoLazyFrame"]
-"""Anything which can be converted to a Narwhals DataFrame or LazyFrame.
-
-Use this if your function can accept an object which can be converted to either
-`nw.DataFrame` or `nw.LazyFrame` and it doesn't care about its backend.
-
-Examples:
-    >>> import narwhals as nw
-    >>> from narwhals.typing import IntoFrame
-    >>> def agnostic_columns(df_native: IntoFrame) -> list[str]:
-    ...     df = nw.from_native(df_native)
-    ...     return df.collect_schema().names()
-"""
-
 Frame: TypeAlias = Union["DataFrame[Any]", "LazyFrame[Any]"]
 """Narwhals DataFrame or Narwhals LazyFrame.
 
@@ -157,51 +121,6 @@ Examples:
     ...     return df.columns
 """
 
-IntoSeries: TypeAlias = "NativeSeries"
-"""Anything which can be converted to a Narwhals Series.
-
-Use this if your function can accept an object which can be converted to `nw.Series`
-and it doesn't care about its backend.
-
-Examples:
-    >>> from typing import Any
-    >>> import narwhals as nw
-    >>> from narwhals.typing import IntoSeries
-    >>> def agnostic_to_list(s_native: IntoSeries) -> list[Any]:
-    ...     s = nw.from_native(s_native)
-    ...     return s.to_list()
-"""
-
-IntoFrameT = TypeVar("IntoFrameT", bound="IntoFrame")
-"""TypeVar bound to object convertible to Narwhals DataFrame or Narwhals LazyFrame.
-
-Use this if your function accepts an object which is convertible to `nw.DataFrame`
-or `nw.LazyFrame` and returns an object of the same type.
-
-Examples:
-    >>> import narwhals as nw
-    >>> from narwhals.typing import IntoFrameT
-    >>> def agnostic_func(df_native: IntoFrameT) -> IntoFrameT:
-    ...     df = nw.from_native(df_native)
-    ...     return df.with_columns(c=nw.col("a") + 1).to_native()
-"""
-
-IntoDataFrameT = TypeVar("IntoDataFrameT", bound="IntoDataFrame")
-"""TypeVar bound to object convertible to Narwhals DataFrame.
-
-Use this if your function accepts an object which can be converted to `nw.DataFrame`
-and returns an object of the same class.
-
-Examples:
-    >>> import narwhals as nw
-    >>> from narwhals.typing import IntoDataFrameT
-    >>> def agnostic_func(df_native: IntoDataFrameT) -> IntoDataFrameT:
-    ...     df = nw.from_native(df_native, eager_only=True)
-    ...     return df.with_columns(c=df["a"] + 1).to_native()
-"""
-
-IntoLazyFrameT = TypeVar("IntoLazyFrameT", bound="IntoLazyFrame")
-
 FrameT = TypeVar("FrameT", "DataFrame[Any]", "LazyFrame[Any]")
 """TypeVar bound to Narwhals DataFrame or Narwhals LazyFrame.
 
@@ -232,21 +151,6 @@ Examples:
 
 LazyFrameT = TypeVar("LazyFrameT", bound="LazyFrame[Any]")
 SeriesT = TypeVar("SeriesT", bound="Series[Any]")
-
-IntoSeriesT = TypeVar("IntoSeriesT", bound="IntoSeries")
-"""TypeVar bound to object convertible to Narwhals Series.
-
-Use this if your function accepts an object which can be converted to `nw.Series`
-and returns an object of the same class.
-
-Examples:
-    >>> import narwhals as nw
-    >>> from narwhals.typing import IntoSeriesT
-    >>> def agnostic_abs(s_native: IntoSeriesT) -> IntoSeriesT:
-    ...     s = nw.from_native(s_native, series_only=True)
-    ...     return s.abs().to_native()
-"""
-
 DTypeBackend: TypeAlias = 'Literal["pyarrow", "numpy_nullable"] | None'
 SizeUnit: TypeAlias = Literal[
     "b",
@@ -339,13 +243,6 @@ UniqueKeepStrategy: TypeAlias = Literal["any", "first", "last", "none"]
 - *"last"*: Keep last unique row.
 """
 
-LazyUniqueKeepStrategy: TypeAlias = Literal["any", "none"]
-"""Which of the duplicate rows to keep.
-
-- *"any"*: Does not give any guarantee of which row is kept.
-- *"none"*: Don't keep duplicate rows.
-"""
-
 ModeKeepStrategy: TypeAlias = Literal["any", "all"]
 """Which of the mode's to keep.
 
@@ -439,6 +336,15 @@ IntoArrowSchema: TypeAlias = "pa.Schema | Mapping[str, pa.DataType]"
 IntoPolarsSchema: TypeAlias = "pl.Schema | Mapping[str, pl.DataType]"
 IntoPandasSchema: TypeAlias = Mapping[str, PandasLikeDType]
 
+FileSource: TypeAlias = "str | os.PathLike[str]"
+"""Path to a file.
+
+Either a string or an object that implements [`__fspath__`], such as [`pathlib.Path`].
+
+[`__fspath__`]: https://docs.python.org/3/library/os.html#os.PathLike
+[`pathlib.Path`]: https://docs.python.org/3/library/pathlib.html#pathlib.Path
+"""
+
 
 # Annotations for `__getitem__` methods
 _T = TypeVar("_T")
@@ -475,6 +381,8 @@ __all__ = [
     "IntoExpr",
     "IntoFrame",
     "IntoFrameT",
+    "IntoLazyFrame",
+    "IntoLazyFrameT",
     "IntoSeries",
     "IntoSeriesT",
     "LazyAllowed",
