@@ -86,6 +86,8 @@ def test_lazy(
     ):  # pragma: no cover
         # https://github.com/duckdb/duckdb/issues/18297
         request.applymarker(pytest.mark.xfail)
+    if "pandas_nullable" in str(constructor_eager):
+        pytest.importorskip("pyarrow")
 
     is_spark_connect = os.environ.get("SPARK_CONNECT", None)
     if is_spark_connect is not None and impl.is_pyspark():  # pragma: no cover
