@@ -34,8 +34,10 @@ def test_split_list_get(request: pytest.FixtureRequest, constructor: Constructor
     if any(backend in str(constructor) for backend in ("dask", "cudf")):
         request.applymarker(pytest.mark.xfail)
 
-    if "pandas" in str(constructor) and PANDAS_VERSION < (2, 2):
-        pytest.skip()
+    if "pandas" in str(constructor):
+        if PANDAS_VERSION < (2, 2):
+            pytest.skip()
+        pytest.importorskip("pyarrow")
     if (
         constructor.__name__.startswith("pandas")
         and "pyarrow" not in constructor.__name__
